AmplifyHttpClient class

Base client for Amplify HTTP operations.

Inheritance

Constructors

AmplifyHttpClient(DependencyManager dependencies, {AWSHttpClient? baseClient})
Base client for Amplify HTTP operations.

Properties

baseClient AWSHttpClient
Overriding this will change the underlying send method without interferring with transformations from transformRequest and transformResponse.
final
hashCode int
The hash code for this object.
no setterinherited
onBadCertificate BadCertificateCallback
Callback for VM clients when an SSL exception occurs due to an untrusted or unverifiable certificate.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportedProtocols SupportedProtocols
The supported HTTP protocols, used for negotiating with remote servers.
getter/setter pairinherited

Methods

close({bool force = false}) Future<void>
Closes the resource and all connected objects.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(AWSBaseHttpRequest request, {FutureOr<void> onCancel()?}) AWSHttpOperation<AWSBaseHttpResponse>
Do not override this method on AWSBaseHttpClient.
inherited
toString() String
A string representation of this object.
inherited
transformRequest(AWSBaseHttpRequest request) Future<AWSBaseHttpRequest>
Transforms a request before sending.
override
transformResponse(AWSBaseHttpResponse response) Future<AWSBaseHttpResponse>
Transforms a response before returning from send.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited