AmplifyPluginKey<P extends AmplifyPluginInterface> class
abstract
A plugin identifier which can be passed to a category's getPlugin method
to retrieve a plugin-specific category wrapper.
- Mixed-in types
- Implementers
Constructors
- AmplifyPluginKey()
-
A plugin identifier which can be passed to a category's
getPluginmethod to retrieve a plugin-specific category wrapper.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- runtimeTypeName → String
-
The string value of runtimeType, saving a runtime lookup and preventing
obfuscation during web compilation.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited