AmplifyUserAgent class

Aggregates user agent values throughout the Amplify categories.

Constructors

AmplifyUserAgent()
Aggregates user agent values throughout the Amplify categories.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addComponent(String component) → void
Adds a component to the user agent header.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
runWith<R>(R fn(), {required void updates(AmplifyUserAgent)}) → R
Runs fn with the given updates applied to this user agent.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited