AuthUser class Auth

Mixed-in types

Constructors

AuthUser({required String userId, required String username, required SignInDetails signInDetails})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
runtimeTypeName → String
The string value of runtimeType, saving a runtime lookup and preventing obfuscation during web compilation.
no setteroverride
signInDetails → SignInDetails
final
userId → String
final
username → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
Serializes this as a JSON object.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited