LogLevel enum
The different levels of logging.
- Inheritance
- Implemented types
- Available extensions
Values
- verbose → const LogLevel
-
Logs for showing behavior of particular components/flows.
Note: May contain information inappropriate for emission into production environments.
- debug → const LogLevel
-
Logs for understanding system behavior.
Note: May contain information inappropriate for emission into production environments.
- info → const LogLevel
-
Logs providing terse info about general operation and flow of software.
- warn → const LogLevel
-
Logs indicating potential issues.
- error → const LogLevel
-
Logs when system is not operating as expected.
- none → const LogLevel
-
Prevents any logs from being emitted.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
compareTo(
LogLevel other) → int -
Compares this object to another object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator <(
LogLevel value) → bool -
operator <=(
LogLevel value) → bool -
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator >(
LogLevel value) → bool -
operator >=(
LogLevel value) → bool