PaginatedResult<T extends Model> class
Constructors
-
PaginatedResult(List<
T?> items, int? limit, String? nextToken, Map<String, dynamic> ? filter, ModelType<T> modelType, GraphQLRequest<PaginatedResult< ? requestForNextResult)T> > -
const
Properties
-
filter
→ Map<
String, dynamic> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasNextResult → bool
-
Returns
trueif there is more data to fetch beyond the data contained in this response. Iftrue, the request for the next page of data can be obtained with.requestForNextResult.no setter -
items
→ List<
T?> -
Model instances for this set of results.
final
- limit → int?
-
final
-
modelIdentifier
→ ModelIdentifier<
Model> -
no setterinherited
-
modelType
→ ModelType<
T> -
final
- nextToken → String?
-
final
-
requestForNextResult
→ GraphQLRequest<
PaginatedResult< ?T> > -
If there is more data than is contained in this response, returns the
request for the next chunk of data, where
limitwill be the same as the original request. Returnsnullif no more data.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getInstanceType(
) → PaginatedModelType< T> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
override
-
toMap(
) → Map< String, Object?> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited