PinpointEventSource enum

The source of a push notification.

Pinpoint offers two ways of sending push notifications to users campaigns and journeys.

See also: Campaigns Journeys

Inheritance
Available extensions
Annotations
  • @Deprecated('this enum will be private in the next major version')

Values

campaign → const PinpointEventSource
const PinpointEventSource('campaign')
journey → const PinpointEventSource
const PinpointEventSource('journey')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PinpointEventSource>
A constant List of the values in this enum, in order of their declaration.