StateMachineToken<Event extends ManagerEvent, State extends ManagerState, ManagerEvent extends StateMachineEvent<Object, Object>, ManagerState extends StateMachineState<Object>, Manager extends StateMachineManager<ManagerEvent, ManagerState, Manager>, M extends StateMachine<Event, State, ManagerEvent, ManagerState, Manager>> class final

A marker for state machine types to improve DX with generic functions.

Inheritance

Constructors

StateMachineToken()
A marker for state machine types to improve DX with generic functions.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type Type
The type identified by this token.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited