StorageRemoveRequest class

Presents a storage copy request.

Constructors

StorageRemoveRequest({required StoragePath path, StorageRemoveOptions? options})
Presents a storage copy request.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
options StorageRemoveOptions?
Configurable options of the StorageRemoveRequest.
final
path StoragePath
The object key to be removed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited