UpdateUserAttributeResult class Auth

Wraps the result of an update user attribute operation.

Mixed-in types
Annotations

Constructors

UpdateUserAttributeResult({required bool isUpdated, required AuthNextUpdateAttributeStep nextStep})
Wraps the result of an update user attribute operation.
const
UpdateUserAttributeResult.fromJson(Map<String, Object?> json)
Wraps the result of an update user attribute operation.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isUpdated → bool
True if the user attribute has now been updated. False if it has not yet been updated.
final
nextStep → AuthNextUpdateAttributeStep
Contains details about the next step in the user attribute update process (or whether the flow is now done).
final
props → List<Object?>
The type's equatable properties.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
runtimeTypeName → String
The string value of runtimeType, saving a runtime lookup and preventing obfuscation during web compilation.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
Serializes this as a JSON object.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited