AuthSignInStep enum Auth
The current step in the sign in flow.
Values
- continueSignInWithMfaSelection → const AuthSignInStep
-
The sign-in is not complete and the user must select and set up an MFA method.
- continueSignInWithMfaSetupSelection → const AuthSignInStep
-
The sign-in is not complete and the user must select an MFA method to setup.
- continueSignInWithTotpSetup → const AuthSignInStep
-
The sign-in is not complete and a TOTP authenticator app must be registered before continuing.
- continueSignInWithEmailMfaSetup → const AuthSignInStep
-
The sign-in is not complete and an Email MFA must be set up before continuing.
- continueSignInWithFirstFactorSelection → const AuthSignInStep
-
The sign-in is not complete and the user must select a first factor method.
- confirmSignInWithSmsMfaCode → const AuthSignInStep
-
The sign-in is not complete and must be confirmed with an SMS code.
- confirmSignInWithTotpMfaCode → const AuthSignInStep
-
The sign-in is not complete and must be confirmed with a TOTP code from a registered authenticator app.
- confirmSignInWithOtpCode → const AuthSignInStep
-
The sign-in is not complete and must be confirmed with an email code.
- confirmSignInWithNewPassword → const AuthSignInStep
-
The sign-in is not complete and must be confirmed with the user's new password.
- confirmSignInWithCustomChallenge → const AuthSignInStep
-
The sign-in is not complete and must be confirmed with the answer to a custom challenge.
- confirmSignInWithOtp → const AuthSignInStep
-
The sign-in is not complete and must be confirmed with an one time password code.
- confirmSignInWithPassword → const AuthSignInStep
-
The sign-in is not complete and must be confirmed with a password.
- resetPassword → const AuthSignInStep
-
The sign-in is not complete and the user must reset their password before proceeding.
- confirmSignUp → const AuthSignInStep
-
The sign-in is not complete and the user's sign up must be confirmed before proceeding.
- done → const AuthSignInStep
-
The sign-in is complete.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AuthSignInStep> - A constant List of the values in this enum, in order of their declaration.